%define __cmake_in_source_build 1
# Ikona's Cargo.toml causes % cargo_prep to fail due to it being a workspace.
# See https://bugzilla.redhat.com/show_bug.cgi?id=1823922.
# And even if that did work, Ikona would have issues due to circular dependencies
# being autogenerated. And even if *that* did work, the crate versions offered in repos
# won't satisfy Ikona's dependencies. Hooray.
%global bundled_rust_deps 1

Name:           ikona
Version:        1.0
Release:        10%{?dist}
Summary:        Icon Preview designed for Plasma

License:        GPLv2+
URL:            https://invent.kde.org/KDE/%{name}
Source0:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz
Source1:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.cargo.vendor.tar.xz
Patch0:         linking.patch

BuildRequires:  appdata-tools
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  pkgconfig

BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(KF5Plasma)
BuildRequires:  cmake(KF5PlasmaQuick)
BuildRequires:  cmake(KF5I18n)

BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(cairo-png)
BuildRequires:  pkgconfig(cairo-gobject)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(pangoft2)

BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5Widgets)

%if 0%{?bundled_rust_deps}
BuildRequires:  cargo
BuildRequires:  rust
%else
BuildRequires:  rust-packaging
%endif

Requires:       kf5-kirigami2
Requires:       kf5-plasma

%description
A utility to preview icons as they are being made.

%prep
%setup -q
%patch0
%if 0%{?bundled_rust_deps}
  cp %{SOURCE1} %{name}.cargo.vendor.tar.xz
%else
  pushd src/rs
    rm -rf vendor .cargo Cargo.lock
    %cargo_prep
    %cargo_generate_buildrequires
  popd
%endif

%build
%cmake
%make_build

%install
%make_install
%find_lang ikona ikona-qml.lang
%find_lang ikonacli ikona-cli.lang

%check
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/*.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/*.desktop

%package cli
Summary: Access %{name}'s functionality from the command line

%description cli
%{name}-cli is a command-line utility allowing you to manipulate icons from
the command line.

%package cli-bash-completions
Summary: Bash completions for %{name}-cli
Requires: %{name}-cli
Requires: bash
Supplements: (%{name}-cli and bash)
BuildArch: noarch

%description cli-bash-completions
Bash completions for %{name}-cli.

%package cli-zsh-completions
Summary: ZSH completions for %{name}-cli
Requires: %{name}-cli
Requires: zsh
Supplements: (%{name}-cli and zsh)
BuildArch: noarch

%description cli-zsh-completions
ZSH completions for %{name}-cli.

%package cli-fish-completions
Summary: Fish completions for %{name}-cli
Requires: %{name}-cli
Requires: fish
Supplements: (%{name}-cli and fish)
BuildArch: noarch

%description cli-fish-completions
Fish completions for %{name}-cli.

%files cli -f ikona-cli.lang
%{_bindir}/ikona-cli

%files cli-zsh-completions
%{_datadir}/zsh/site-functions/_ikona-cli

%files cli-fish-completions
%dir %{_datadir}/fish/
%dir %{_datadir}/fish/completions/
%{_datadir}/fish/completions/ikona-cli.fish

%files cli-bash-completions
%dir %{_prefix}%{_sysconfdir}/bash_completion.d/
%{_prefix}%{_sysconfdir}/bash_completion.d/ikona-cli.bash

%files -f ikona-qml.lang
%license LICENSE
%doc README.md
%{_bindir}/ikona
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%{_datadir}/applications/*.desktop
%{_datadir}/metainfo/*.appdata.xml

%changelog
* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Thu Jul 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Sep 23 2020 Jeff Law <law@redhat.com> - 1.0-5
- Use cmake_in_source_build to fix FTBFS due to recent cmake macro changes

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-4
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Fri Apr 17 2020 Carson Black <uhhadd@gmail.com> - 1.0-2
- Update to version 1.0

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Jan 20 2020 Carson Black <uhhadd@gmail.com> - 0.7.1-2
- Add ExclusiveArch so build doesn't fail due to arches missing QtWebEngine

* Mon Dec 16 2019 Carson Black <uhhadd@gmail.com> - 0.7.1-1
- Initial packaging for Fedora based off of specfile for openSUSE
- Replace openSUSE-isms with Fedora-isms

* Sun Oct  6 2019 Carson Black <uhhadd@gmail.com> - 0.7.1
- Disable services so version won't get changed

* Thu Sep 19 2019 Carson Black uhhadd@gmail.com - 0.7.1
- Update to version v0.7.1

* Wed Sep 11 2019 Carson Black uhhadd@gmail.com - 0.7+git1.827b694
- Update to version v0.7+git1.827b694:
  * Remove unused templates from CMakeLists.txt

* Wed Sep 11 2019 Carson Black uhhadd@gmail.com - 0.7+git0.4df67cf
- Update to version v0.7+git0.4df67cf:
  * Update appdata & desktop metadata
  * CMake
  * Montages, but on the command line
  * Montages
  * Removed CMakeLists.txt.
  * Use checked instead of disabled to show current view
  * Change default homepage from HIG home to HIG icons
  * Use QtQuick.Dialogs instead of kdialog and remove unused imports
  * Update README.md
  * Tidy up the repository and the program

* Sat Aug 10 2019 Carson Black <uhhadd@gmail.com> - 0.6.1.1
- Update to 0.6.1.1, bugfix for stylesheet injection

* Sat Aug 10 2019 Carson Black <uhhadd@gmail.com> - 0.6.1
- Update to 0.6.1

* Mon Jul 15 2019 Carson Black <uhhadd@gmail.com> - 0.5.2.4
- Cleaned up specfile
- Add runtime dependencies
- Use reverse domain name
- Update to 0.5.2.4

* Thu Jul 11 2019 Carson Black <uhhadd@gmail.com> - 0.5.2.1
- Update to 0.5.2.1
- Back to CMake because Meson bugs

* Thu Jul 11 2019 Carson Black <uhhadd@gmail.com> - 0.5.2
- Update to 0.5.2
- Meson port

* Thu Jul 11 2019 Carson Black <uhhadd@gmail.com> - 0.5
- Update to 0.5
- Tidy up package files

* Tue Jul  2 2019 Carson Black <uhhadd@gmail.com> - 0.4
- Update to 0.4

* Wed Jun  5 2019 Carson Black <uhhadd@gmail.com> - 0.2.3
- Update to 0.2.3
- Project renamed to Ikona

* Wed Jun  5 2019 Carson Black <uhhadd@gmail.com> - 0.2.0
- Update to 0.2.0
- Changeable colors, small icon view, and fancier icon

* Tue Jun  4 2019 Carson Black <uhhadd@gmail.com> - 0.1.0
- Initial package
